/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.plugins.sql

import groovy.sql.Sql
import javax.sql.DataSource
import org.apache.commons.lang.StringEscapeUtils
import java.sql.Statement
import org.apache.commons.lang.math.NumberUtils

/**
 * Created by IntelliJ IDEA.
 * User: tbarker
 * Date: 7/18/11
 * Time: 3:38 PM
 */
class SqlBatch extends Sql {

    SqlBatch(DataSource dataSource) {
        super(dataSource)
    }

    int[] insertBatch(String table, batch) {

        withBatch {statement ->
            if (batch instanceof List) {
                batch.each {record ->
                    def insert = getInsertStatement(table, record)
                    statement.addBatch(insert)
                }
            } else {
                def insert = getInsertStatement(table, batch)
                statement.addBatch(insert)
            }
        }
    }

    private static String getInsertStatement(String table, Map values) {

        StringBuffer insert = new StringBuffer("insert into ")
        StringBuffer valuesToInsert = new StringBuffer("values (")
        insert.append(table)
        insert.append(" (")
        values.each {key, value ->
            insert.append(key)
            insert.append(", ")
            String valueText = String.valueOf(value)

            if (NumberUtils.isNumber(valueText)) {
                valuesToInsert.append(value)
            } else {
                valuesToInsert.append("'")
                valuesToInsert.append(StringEscapeUtils.escapeSql(value))
                valuesToInsert.append("'")
            }

            valuesToInsert.append(", ")
        }
        insert.delete(insert.length() - 2, insert.length())
        insert.append(") ")
        valuesToInsert.delete(valuesToInsert.length() - 2, valuesToInsert.length())
        valuesToInsert.append(")")

        return insert.append(valuesToInsert).toString()
    }


}
